@@ -14,11 +14,6 @@ import aws_cdk.aws_iam
 import aws_cdk.aws_kms
 import aws_cdk.core
 import constructs
-
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-sns", "1.33.0", __name__[0:-6], "aws-sns@1.33.0.jsii.tgz")
-
-__all__ = [
-    "__jsii_assembly__",
-]
+__all__ = []
 
 publication.publish()
